
from relpath import add_import_path
add_import_path("../")
# task management tool
from _develop_tskr import tskr

tskr()
